/* REST API GENERAL FUNCTIONS */
/**
 * @Author : Jahia(rahmed)
 * This function make an ajax call to the Jahia API and return the result of this call
 * @param workspace : the workspace to use on this call (live, default)
 * @param locale : the locale to use in ISO 639-1
 * @param way : the way to find the JCR entity on which make the call (nodes, byPath, byType)
 * @param method : the METHOD to call (GET, POST, PUT, DELETE ...)
 * @param endOfURI : the information needed to complete the entity search (id if the way is nodes, path if byPath and type if byType) with the options (/propertie/<propertieName> for example)
 * @param json : the Json to pass with the call
 * @param callback : the callback function for the request (Optional)
 * @param errorCallback : the error function for the request (Optional)
 * @return callResult : the result of the Ajax call
 */
function jahiaAPIStandardCall(workspace, locale, way, endOfURI, method, json, callback, errorCallback) {
    var callResult;
    var url = API_URL_START + '/' + workspace + '/' + locale + '/' + way + (way=='paths'?'':'/') + endOfURI;
    var httpResult = $.ajax({
        contentType: 'application/json',
        data: json,
        dataType: 'json',
        processData: false,
        type: method,
        url: url,
        async:true,
        success: function (result) {
            if (!(result === undefined)) {
                result['status'] = httpResult.status;
                //calling the callback
                if (!(callback === undefined)) {
                    callback(result, json);
                }
                callResult = result;
            } else {
                if (!(callback === undefined)) {
                    callback();
                }
            }
        },
        error: function (result) {
            result['status'] = httpResult.status;
            return errorCallback(result, json);
        }
    });

    return callResult;
}

/**
 * @Author : Jahia(rahmed)
 * This function is called after the user picture Upload
 * to check if the avatar is created
 * @param testUrl: the file url to test
 * @return: 200 for success and 0 or negative value on error
 */
function urlExists(testUrl) {
    var http = jQuery.ajax({
        type: 'GET',
        url: testUrl,
        async: false
    });
    return http.status;
}

/* Edit User Details User Picture */
/**
 * @Author : Jahia(rahmed)
 * This function Upload a picture the user picked and update his user picture property with it
 * The picture to upload is directly picked from the form
 * @param imageId : The id of the input file form field
 * @param locale: The locale for the API call URL build
 * @param nodepath : The path of the user node for the API call URL build
 * @param userId : The user Id for the picture property Update
 * @param callbackFunction : the callback function
 * @param errorFunction : The error callback function
 */
function updatePhoto(imageId, locale, nodePath, userId, callbackFunction, errorFunction) {
    //checking if the file input has been filled
    jahiaAPIStandardCall('default', locale, 'paths', nodePath + '/files/profile', 'GET', null, function () {
        doUpload(imageId, locale, nodePath, userId, callbackFunction, errorFunction);
    }, function () {
        //create profile
        console.log('profile folder does not exist, we are creating it.');
        var jsonData = {"name": "files", "type": "jnt:folder"};
        jahiaAPIStandardCall('default', locale, 'nodes', userId + '/children/files', 'PUT', JSON.stringify(jsonData), function (result) {
            jahiaAPIStandardCall('default', locale, 'nodes', result.id + '/children/profile', 'PUT', JSON.stringify(jsonData), function (result) {
                console.log(JSON.stringify(result));
                doUpload(imageId, locale, nodePath, userId, callbackFunction, errorFunction);
            });
        });
    });
}

function doUpload(imageId, locale, nodePath, userId, callbackFunction, errorFunction) {
    var uploadUrl = API_URL_START + '/default/' + locale + '/paths' + nodePath + '/files/profile';
    //Upload the picture
    $.ajaxFileUpload({
        url: uploadUrl,
        secureuri: false,
        fileElementId: imageId,
        dataType: 'json',
        success: function (result) {
            console.log('SUCCESS');
            console.log(result);
            console.log(uploadUrl);
            console.log(imageId);
            if (result['exception'] != undefined) {
                if (result['status'] === undefined) {
                    result['status'] = 404;
                }
                errorFunction(result);
            }
            else {
                var fileId = result['id'];
                var fileName = result['name'];
                var filePath = URL_FILES + '/files/profile/' + fileName;
                //JSon Serialized String
                var jsonData;
                var endOfURI = userId + '/properties/j__picture';

                //Creating the Json String to send with the PUT request
                jsonData = JSON.stringify({value: fileId});
                //Requesting the Jahia API to update the user picture
                jahiaAPIStandardCall('default', locale, 'nodes', endOfURI, 'PUT', jsonData, function () {
                    //Check If Jahia had the time to create the Avatar
                    //building the avatar URL
                    var imageUrl = filePath + '?t=avatar_120';
                    var avatarExists = false;
                    var ExistsCode = -1;
                    intervalURLChecker = window.setInterval(function () {
                        ExistsCode = urlExists(imageUrl);
                        if (ExistsCode <= 300) {
                            //Avatar has been found refreshing the profile display ...
                            avatarExists = true;
                            window.clearInterval(intervalURLChecker);
                            callbackFunction();
                        }
                    }, 500);
                }, errorFunction);
            }
        },
        error: function (result) {
            console.log('****************** ERROR ********************');
            console.log(result);
            console.log(uploadUrl);
            console.log(imageId);
            if (result['status'] === undefined) {
                result['status'] = 404;
            }
            errorFunction(result);
        }
    });
}

/**
 * @Author : Jahia(rahmed)
 * Edit User Details Callback Function
 * This function is called after the user properties Update in error cases
 * It formats and displays the Jahia API error messages
 * @param result : The PUT request result
 * @param sent : The sent Json with the PUT request (to check for the preferredLanguage Properties)
 */
var formError = function (result, sent) {
    var resultObject = null;

    if (result['status'] > 300) {
        if (result['status'] == 401) {
            //Lost session redirecting to login
            console.log('LOGIN ERROR');
        }
        else if (result['status'] >= 400 && result['status'] < 500) {
            //other errors displaying default message
            console.log('STATUS : ' + result['status']);
        }
        else if (result['status'] == 500) {
            //server error trying to get message from Api
            if (result.responseJSON != undefined) {
                //trying to get message in Json
                resultObject = {"message": "" + result.responseJSON.message + "", "properties": []};
            }
            else if (result['message'] != undefined) {
                //trying to get message directly from result
                resultObject = {"message": "" + result['message'] + "", "properties": []};
            }
            if (resultObject != null) {
                //formatting the message (replacing the j:properties by their names)

                //looking for JCR property name
                var propertiesArray = new Array();
                if (result.responseJSON.message.indexOf("j:") != -1) {
                    //split message on spaces
                    propertiesArray = result.responseJSON.message.split(" ");

                    for (var property = 0; property < propertiesArray.length; property++) {
                        if (propertiesArray[property].indexOf('j:') != -1) {
                            if (resultObject['properties']) {
                                if (!resultObject['properties'].push) {
                                    resultObject['properties'] = [resultObject['properties']];
                                }
                                resultObject['properties'].push(propertiesArray[property] || '');
                            } else {
                                resultObject['properties'] = {"keys": propertiesArray[property] || ''};
                            }
                        }
                    }
                }
                var errorMessage = '' + resultObject['message'];

                var propertiesArray = resultObject['properties'];

                for (var propertyName = 0; propertyName < propertiesArray.length; propertyName++) {
                    errorMessage = errorMessage.replace(propertiesArray[propertyName], propertiesNames[propertiesArray[propertyName]]);
                }

                //displaying formatted error message
                console.log(errorMessage);
            }
            else {
                //default error message
                console.log('ERROR else')
            }
        }
    }
    return resultObject;
}