package jnt_calendar.json

import org.apache.commons.lang.StringUtils
import org.apache.commons.lang.WordUtils
import org.apache.taglibs.standard.functions.Functions
import org.jahia.services.content.JCRNodeWrapper
import org.jahia.services.content.JCRSessionWrapper
import org.jahia.services.usermanager.JahiaUserManagerService
import org.jahia.taglibs.user.User
import org.jahia.utils.WebUtils
import org.jahia.utils.i18n.Messages
import org.joda.time.format.ISODateTimeFormat

import javax.jcr.NodeIterator
import javax.jcr.RepositoryException
import javax.jcr.query.Query
import javax.jcr.query.QueryResult

/**
 * @author  : dgaillard
 * created  : 05/12/2015
 */

JCRNodeWrapper docspaceNode = renderContext.mainResource.getNode().getSession().getNode(renderContext.request.getParameter("docspaceNode"));
JCRSessionWrapper session = docspaceNode.session;
def from = ISODateTimeFormat.dateTime().print(new Long(renderContext.request.getParameter("from").toString()));
def to = ISODateTimeFormat.dateTime().print(new Long(renderContext.request.getParameter("to").toString()));
String queryTask = "select * from [jnt:task] as t where isdescendantnode(t,['" + docspaceNode.path + "']) and (([dueDate] IS NULL and [jcr:created] >= CAST('"+from+"' AS DATE) and [jcr:created] <= CAST('"+to+"' AS DATE)) or ([dueDate] IS NOT NULL and [dueDate] >= CAST('"+from+"' AS DATE) and [dueDate] <= CAST('"+to+"' AS DATE))) order by [jcr:created] desc";
QueryResult queryTaskResult = session.workspace.queryManager.createQuery(queryTask, Query.JCR_SQL2).execute();
NodeIterator tni = queryTaskResult.getNodes();
int i = 0;
String json = "[";
def jahiaUserManagerService = JahiaUserManagerService.getInstance()
while (tni.hasNext()) {
    JCRNodeWrapper currentTask = (JCRNodeWrapper) tni.next();
    String className;
    String taskType;
    String displayURL;
    String assigneeUserKey = "";
    json += "{";
    json += "\"id\": " + i + ",";
    json += "\"title\": \"" + Functions.escapeXml(currentTask.getProperty("jcr:title").getString()) + "\",";
    assigneeUserKey = ((currentTask.hasProperty("assigneeUserKey") && StringUtils.isNotEmpty(currentTask.getProperty("assigneeUserKey").getString()))?User.userFullName(jahiaUserManagerService.lookup(StringUtils.substringAfterLast(currentTask.getProperty("assigneeUserKey").getString(), "/"))):Messages.get("resources.workspace-factory", "jnt_task.docspace.notAssign", renderContext.mainResourceLocale));
    json += "\"assignee\": \"" + assigneeUserKey + "\",";
    if (currentTask.hasProperty("description")) {
        json += "\"description\": \"" + Functions.escapeXml(currentTask.getProperty("description").getString()) + "\",";
        json += "\"descriptionLabel\": \"" + Functions.escapeXml(WordUtils.abbreviate(currentTask.getProperty("description").getString(), 75, 90, " ...")) + "\",";
    }
    json += "\"end\": \"" + (currentTask.hasProperty("dueDate")?currentTask.getProperty("dueDate").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ"):currentTask.getProperty("jcr:created").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ")) + "\",";
    json += "\"priority\": \"" + Messages.get("resources.workspace-factory", "jnt_task.docspace.priority." + currentTask.getProperty("priority").getString(), renderContext.mainResourceLocale) + "\",";
    json += "\"priorityLabel\": \"" + currentTask.getProperty("priority").getString() + "\",";
    if (currentTask.getProperty("type").getString().equals("docspace-task-on-file")) {
        className = (currentTask.getProperty("priority").getString().equals("high")?"event-important":"event-info");
        taskType = Messages.get("resources.workspace-factory", "wsf.label.document", renderContext.mainResourceLocale);
        displayURL = url.context + url.base + WebUtils.escapePath(StringUtils.substringBeforeLast(currentTask.path, "/tasks")) + ".workspace-document-details.html";
    } else if (currentTask.getProperty("type").getString().equals("docspace-task-on-note")) {
        className = (currentTask.getProperty("priority").getString().equals("high")?"event-important":"event-warning");
        taskType = Messages.get("resources.workspace-factory", "docnt_note", renderContext.mainResourceLocale);
        displayURL = url.context + url.base + WebUtils.escapePath(StringUtils.substringBeforeLast(currentTask.path, "/tasks")) + ".workspace-note-details.html";
    } else {
        className = (currentTask.getProperty("priority").getString().equals("high")?"event-important":"event-inverse");
        taskType = Messages.get("resources.workspace-factory", "wsf.label.workspace", renderContext.mainResourceLocale);
        if (!currentTask.hasProperty("assigneeUserKey") || (currentTask.hasProperty("assigneeUserKey") && StringUtils.isEmpty(currentTask.getProperty("assigneeUserKey").getString())) || currentTask.getProperty("assigneeUserKey").getString().equals(session.getUserNode().path)) {
            displayURL = url.context + url.baseLive + WebUtils.escapePath(session.getUserNode().path) + ".workspace-user.html?jsite=" + session.getNode("/sites/wsfaccess").identifier;
        } else {
            displayURL = "";
        }
    }
    json += "\"url\": \"" + displayURL + "\",";
    json += "\"taskType\": \"" + taskType + "\",";
    json += "\"state\": \"" + currentTask.getProperty("state").getString() + "\",";
    if (currentTask.getProperty("state").getString().equals("finished")) {
        json += "\"endDate\": \"" + currentTask.getProperty("jcr:lastModified").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ") + "\",";
        className = "";
    }
    json += "\"class\": \"" + className + "\"";

    json += "}";
    if (tni.hasNext()) {
        json += ",";
    }
    i++;
}

String queryWorkflow = "SELECT * FROM [jnt:task] AS task WHERE task.type = 'workflow' and (([dueDate] IS NULL and [jcr:created] >= CAST('"+from+"' AS DATE) and [jcr:created] <= CAST('"+to+"' AS DATE)) or ([dueDate] IS NOT NULL and [dueDate] >= CAST('"+from+"' AS DATE) and [dueDate] <= CAST('"+to+"' AS DATE))) order by [jcr:created] desc";
QueryResult queryWorkflowResult = session.workspace.queryManager.createQuery(queryWorkflow, Query.JCR_SQL2).execute();
NodeIterator wni = queryWorkflowResult.getNodes();

while (wni.hasNext()) {
    JCRNodeWrapper currentWorkflow = (JCRNodeWrapper) wni.next();
    try {
        def targetNode = currentWorkflow.getProperty("targetNode").getNode();
        if (StringUtils.startsWith(targetNode.path, docspaceNode.path)) {
            if (!json.equals("[")) {
                json += ",";
            }
            json += "{";
            json += "\"id\": " + i + ",";
            json += "\"title\": \"" + Functions.escapeXml(currentWorkflow.name) + " - " + Functions.escapeXml(targetNode.name) + "\",";
            json += "\"assignee\": \"" + ((currentWorkflow.hasProperty("assigneeUserKey"))?User.userFullName(jahiaUserManagerService.lookup(StringUtils.substringAfterLast(currentWorkflow.getProperty("assigneeUserKey").getString(), "/"))):Messages.get("resources.workspace-factory", "jnt_task.docspace.notAssign", renderContext.mainResourceLocale)) + "\",";
            json += "\"end\": \"" + (currentWorkflow.hasProperty("dueDate")?currentWorkflow.getProperty("dueDate").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ"):currentWorkflow.getProperty("jcr:created").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ")) + "\",";
            json += "\"url\": \"" + url.context + url.base + WebUtils.escapePath(targetNode.path) + ".workspace-document-details.html" + "\",";
            json += "\"state\": \"" + currentWorkflow.getProperty("state").getString() + "\",";
            if (currentWorkflow.getProperty("state").getString().equals("finished")) {
                json += "\"taskType\": \"" + Messages.get("resources.workspace-factory", "jnt_calendar.finishedWorkflow", renderContext.mainResourceLocale) + "\",";
                json += "\"endDate\": \"" + currentWorkflow.getProperty("jcr:lastModified").getDate().format("yyyy-MM-dd'T'HH:mm:ssZ") + "\",";
                json += "\"class\": \"\",";
                json += "\"finalOutcome\": \"" + currentWorkflow.getProperty("finalOutcome").getString() + "\"";
            } else {
                json += "\"taskType\": \"" + Messages.get("resources.workspace-factory", "jnt_calendar.activeWorkflow", renderContext.mainResourceLocale) + "\",";
                json += "\"class\": \"event-special\"";
            }
            json += "}";
            i++;
        }
    } catch (RepositoryException e) {

    }
}

json += "]";

print "{ \"success\":1,\"result\":"+json+"}";