<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="jcr" uri="http://www.jahia.org/tags/jcr" %>
<%@ taglib prefix="functions" uri="http://www.jahia.org/tags/functions" %>
<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<%@ taglib prefix="template" uri="http://www.jahia.org/tags/templateLib" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/functions" prefix="fn" %>
<%@ taglib prefix="utility" uri="http://www.jahia.org/tags/utilityLib" %>
<%--@elvariable id="currentNode" type="org.jahia.services.content.JCRNodeWrapper"--%>
<%--@elvariable id="out" type="java.io.PrintWriter"--%>
<%--@elvariable id="script" type="org.jahia.services.render.scripting.Script"--%>
<%--@elvariable id="scriptInfo" type="java.lang.String"--%>
<%--@elvariable id="workspace" type="java.lang.String"--%>
<%--@elvariable id="renderContext" type="org.jahia.services.render.RenderContext"--%>
<%--@elvariable id="currentResource" type="org.jahia.services.render.Resource"--%>
<%--@elvariable id="url" type="org.jahia.services.render.URLGenerator"--%>

<template:addResources type="css" resources="loading.css"/>
<template:addResources type="css" resources="workspace.css"/>

<template:addResources type="javascript" resources="jquery.min.js"/>
<template:addResources type="javascript" resources="jquery-ui.min.js"/>
<template:addResources type="javascript" resources="bootstrap-modal.js"/>
<template:addResources type="javascript" resources="bootstrap-transition.js"/>
<template:addResources type="javascript" resources="bootbox.min.js"/>
<template:addResources type="javascript" resources="jquery.form.js"/>
<template:addResources type="javascript" resources="loading.js"/>

<template:addResources>
    <script type="text/javascript">
        function createSite() {
            showLoading(wsfi18n['wsf.title.workInProgress']);
            $('#webProjectCreationForm').ajaxSubmit({
                dataType: "json",
                success: function(response) {
                    if (response.warn != undefined) {
                        console.log(response);
                        bootbox.alert(response.warn);
                        hideLoading();
                    } else {
                        window.location.reload();
                    }
                },
                error: function(response) {
                    hideLoading();
                }
            });
            return true;
        }
    </script>
</template:addResources>

<c:set var="nodeType" value="jnt:page" />

<div class="modal-header">
    <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
    <h3>${fn:escapeXml(currentNode.displayableName)}</h3>
</div>

<template:tokenizedForm  allowsMultipleSubmits="true">
    <form class="<c:if test="${not empty currentNode.properties['class']}">${currentNode.properties['class'].string}</c:if>"
          id="webProjectCreationForm" method="post"
          action="<c:url value='${url.base}/sites.adminCreateSite.do'/>" >
        <div class="modal-body">
            <c:if test="${currentNode.properties.stayOnPage.boolean}">
                <input type="hidden" name="jcrRedirectTo" value="<c:url value='${url.base}${functions:escapePath(renderContext.mainResource.node.path)}'/>"/>
            </c:if>

            <div class="control-group">
                <label class="control-label" for="siteTitle">
                    <fmt:message key="wsf.label.title"/> (*)
                </label>
                <div class="controls">
                    <input type="text" name="siteTitle" id="siteTitle" value=""/>
                </div>
            </div>

            <div class="control-group">
                <label class="control-label" for="siteKey">
                    <fmt:message key="serverSettings.docspace.siteKey"/> (*)
                </label>
                <div class="controls">
                    <input type="text" name="siteKey" id="siteKey" value=""/>
                </div>
            </div>

            <c:choose>
                <c:when test="${currentNode.properties['useServerName'].boolean}">
                    <div class="control-group">
                        <label class="control-label" for="siteServerName${currentNode.name}">
                            <fmt:message key="serverSettings.docspace.serverName"/> (*)
                        </label>
                        <div class="controls">
                            <input type="text" name="siteServerName" id="siteServerName" value="localhost"/>
                        </div>
                    </div>
                </c:when>
                <c:otherwise>
                    <input type="hidden" name="siteServerName" value="localhost"/>
                </c:otherwise>
            </c:choose>

            <c:if test="${currentNode.properties['useDescription'].boolean}">
                <div class="control-group">
                    <label class="control-label" for="siteDescr">
                        <fmt:message key="wsf.label.description"/>
                    </label>
                    <div class="controls">
                        <textarea name="siteDescr" id="siteDescr" value=""></textarea>
                    </div>
                </div>
            </c:if>


            <c:choose>
                <c:when test="${currentNode.properties['useTemplatesSet'].boolean}">
                    <div class="control-group">
                        <label class="control-label" for="templatesSet">
                            <fmt:message key="serverSettings.docspace.templateSet"/>
                        </label>
                        <div class="controls">
                            <select name="templatesSet$" id="templatesSet">
                                <jcr:node var="sets" path="/modules"/>
                                <c:forEach items="${sets.nodes}" var="set">
                                    <c:if test="${set.properties['j:moduleType'].string eq 'templatesSet'}">
                                        <option value="${set.name}">${set.displayableName}</option>
                                    </c:if>
                                </c:forEach>
                            </select>
                        </div>
                    </div>
                </c:when>
                <c:otherwise>
                    <input type="hidden" name="templatesSet" value="${currentNode.properties['defaultTemplatesSet'].node.name}">
                </c:otherwise>
            </c:choose>

            <c:if test="${currentNode.properties['mixLanguage'].boolean}">
                <input type="hidden" name="mixLanguage" value="true">
            </c:if>

            <c:if test="${currentNode.properties['allowsUnlistedLanguages'].boolean}">
                <input type="hidden" name="allowsUnlistedLanguages" value="true">
            </c:if>

            <c:if test="${not empty currentNode.properties['forceLanguage'].string}">
                <input type="hidden" name="language" value="${currentNode.properties['forceLanguage'].string}">
            </c:if>
        </div>

        <div class="modal-footer">
            <button type="button" class="btn" data-dismiss="modal" aria-hidden="true">
                <fmt:message key="wsf.label.close"/>
            </button>
            <button type="button" class="btn btn-primary" id="createSite_button" onclick="createSite()" ${disabled}>
                ${currentNode.properties['buttonLabel'].string}
            </button>
        </div>
    </form>
</template:tokenizedForm>

